from .runner import go
from .pen import Pen
from .pen import Font
from .data import Data
from .master import Master
from .actor import Actor
from .animation import animate

from pgzero import animation,  clock, loaders, music,  rect, runner, screen, constants, keyboard
from pgzero.clock import clock, tick, schedule
from pgzero.loaders import fonts, sounds, root, images
from pgzero.rect import Rect
from pgzero.screen import Screen
from pgzero.constants import mouse
from pgzero.keyboard import keys, keyboard
